import { IEventSource } from '../eventSource';
import { DataManager } from '../kameleoonData';
import { Requester } from '../requester';
import { IVisitorCodeManager } from '../visitorCodeManager';
import { ClientDataType, IStorage } from '../storage';
import { SegmentType } from '../targeting';
import { VariableType } from '../types';
import { EventManager } from '../eventManager';
import { IUrlProvider } from '../requester/urlProvider';
export type ScheduleType = {
    dateStart: string;
    dateEnd: string;
};
export declare enum UpdateType {
    Polling = 0,
    RealTime = 1
}
export type JSONValue = string | number | boolean | {
    [x: string]: JSONValue;
} | JSONValue[];
export type JSONType = Record<string | number | symbol, JSONValue> | null;
export declare enum RuleType {
    TARGETED_DELIVERY = "TARGETED_DELIVERY",
    EXPERIMENTATION = "EXPERIMENTATION"
}
export declare enum FeatureFlagSdkLanguageType {
    ANDROID = "ANDROID",
    SWIFT = "SWIFT",
    JAVA = "JAVA",
    CSHARP = "CSHARP",
    NODEJS = "NODEJS",
    PHP = "PHP",
    RUBY = "RUBY",
    GO = "GO",
    FLUTTER = "FLUTTER",
    REACTJS = "REACTJS"
}
export declare enum FeatureStatus {
    ACTIVATED = "ACTIVATED",
    DEACTIVATED = "DEACTIVATED",
    SCHEDULED = "SCHEDULED"
}
export declare enum CustomDataScope {
    Visit = "VISIT",
    Visitor = "VISITOR",
    Page = "Page"
}
export declare enum ConsentType {
    Required = "REQUIRED",
    NotRequired = "NOT_REQUIRED"
}
export type DeviationType = {
    variationId: string;
    value: number;
};
export type FeatureFlagType = {
    id: number;
    featureKey: string;
    environmentEnabled: boolean;
    variations: FeatureVariationType[];
    defaultVariationKey: string;
    rules: RuleItemType[];
    mutuallyExclusiveGroup?: string | null;
};
export type ExperimentType = {
    experimentId: number;
    variationByExposition: VariationByExpositionType[];
};
export type FeatureVariationType = {
    key: string;
    variables: FeatureVariableType[];
};
export type FeatureVariableType = {
    key: string;
    type: VariableType;
    value: string | number | boolean;
};
export type RuleItemType = {
    type: RuleType;
    id: number;
    respoolTime: number | null;
    order: number;
    exposition: number;
    experimentId: number;
    variationByExposition: VariationByExpositionType[];
    segment: SegmentType | null;
};
export type MappedRuleType = {
    experimentId: number;
    featureId: number;
    variations: Map<string, number>;
};
export type ExperimentInfoType = {
    type: RuleType;
    variations: Map<string, number>;
};
export type VariationByExpositionType = {
    variationKey: string;
    variationId: number;
    exposition: number;
};
export type ConfigurationDataType = {
    featureFlags: FeatureFlagType[];
    configuration: ConfigurationType;
    customData: CustomDataConfigurationType[];
    holdout?: ExperimentType;
};
export type ClientConfigurationDataType = Omit<ConfigurationDataType, 'featureFlags'>;
export type CustomDataConfigurationType = {
    index: number;
    localOnly: boolean;
    isMappingIdentifier: boolean;
    scope: CustomDataScope;
};
export type ConfigurationType = {
    realTimeUpdate: boolean;
    consentType: ConsentType;
    dataApiDomain: string;
};
export type ClientConfigurationParametersType = {
    urlProvider: IUrlProvider;
    updateInterval: number;
    storage: IStorage<ClientDataType>;
    dataManager: DataManager;
    requester: Requester;
    eventSource: IEventSource;
    eventManager: EventManager;
    externalVisitorCodeManager: IVisitorCodeManager;
};
