import { IUrlProvider } from '../requester';
/**
 * @param {number} timestamp - timestamp of when the event has happened
 * */
export type EventHandlerType = (timestamp: number) => void;
/**
 * @param {string} url - url of server sent event server which will be pasted by consumer
 * @param {string} eventType - type of event to be listened for
 * @param {(message: MessageEvent) => void} onEvent  - callback to be executed when event fired
 * */
export type EventSourceOpenParametersType = {
    url: string;
    eventType: string;
    onEvent: (message: MessageEvent) => void;
};
/**
 * @interface an interface of External Event Source which will be used in server sent events operations
 * */
export interface IExternalEventSource {
    /**
     * @method open - opens event source live connection
     * @param {OpenEventSourceParamsType} parameters - parameters to be passed to the event source
     * */
    open: ({ url, eventType, onEvent }: EventSourceOpenParametersType) => void;
    /**
     * @method close - closes event source live connection
     * */
    close: () => void;
    /**
     * @method onError - optional error handler - sets error handler for event source
     * */
    onError?: (callback: (error: Event) => void) => void;
}
/**
 * @param {string} siteCode - site code from the event
 * @param {number} ts - timestamp of when the event has happened
 * */
export type RealTimeEventType = {
    siteCode: string;
    ts: number;
};
export type EventSourceParametersType = {
    siteCode: string;
    urlProvider: IUrlProvider;
    externalEventSource: IExternalEventSource;
};
