import { JSONType } from './clientConfiguration';
import { CustomData, KameleoonDataType } from './kameleoonData';
import { TrackConversionParamsType, FeatureFlagType, GetFeatureFlagVariableParamsType, FeatureVariableResultType, SDKCoreParameters, RemoteVisitorDataParamsType, GetVisitorWarehouseAudienceParamsType, SetUserConsentParametersType, FeatureFlagVariableType, KameleoonVariationType, VariationType, GetVariationParamsType, GetVariationsParamsType, IsFeatureFlagActiveParamsType, SetForcedVariationParametersType } from './types';
import { IKameleoonClient } from './kameleoonClientInterface';
import { EventCallbackType, EventType } from './eventManager';
import { LogLevel } from './logging';
/**
 * @class
 * KameleoonClient - a class for creating kameleoon client instance
 * for communicating with Kameleoon JavaScript SDK Core, when new instance is created
 */
export declare class KameleoonClient implements IKameleoonClient {
    private variationConfiguration;
    private clientConfiguration;
    private dataManager;
    private consentDataStorage;
    private trackingCache;
    private requester;
    private externalPackageInfo;
    private initialized;
    private visitorCodeManager;
    private eventManager;
    private tracker;
    private environment;
    protected readonly stubMode?: boolean;
    /**
     * @param {SDKCoreParameters} sdkCoreParameters - parameters for initializing sdk core
     */
    constructor({ siteCode, dependencies, configuration, internalConfiguration, stubMode }: SDKCoreParameters);
    initialize(): Promise<boolean>;
    addData(visitorCode: string, ...data: KameleoonDataType[]): void;
    getRemoteVisitorData({ visitorCode, shouldAddData, filters, }: RemoteVisitorDataParamsType): Promise<KameleoonDataType[]>;
    trackConversion({ visitorCode, goalId, negative, revenue, metadata, }: TrackConversionParamsType): void;
    flush(visitorCode?: string): void;
    getFeatureFlags(): FeatureFlagType[];
    getVisitorFeatureFlags(visitorCode: string): FeatureFlagType[];
    getVariation({ visitorCode, featureKey, track, }: GetVariationParamsType): VariationType;
    getVariations({ visitorCode, onlyActive, track, }: GetVariationsParamsType): Map<string, VariationType>;
    getActiveFeatureFlags(visitorCode: string): Map<string, KameleoonVariationType>;
    getFeatureFlagVariationKey(visitorCode: string, featureKey: string): string;
    getFeatureFlagVariable({ visitorCode, featureKey, variableKey, }: GetFeatureFlagVariableParamsType): FeatureFlagVariableType;
    getFeatureFlagVariables(visitorCode: string, featureKey: string): FeatureVariableResultType[];
    isFeatureFlagActive(visitorCode: string, featureKey: string): boolean;
    isFeatureFlagActive({ visitorCode, featureKey, track, }: IsFeatureFlagActiveParamsType): boolean;
    getRemoteData(key: string): Promise<JSONType>;
    getVisitorWarehouseAudience({ visitorCode, customDataIndex, warehouseKey, }: GetVisitorWarehouseAudienceParamsType): Promise<CustomData | null>;
    onEvent<E extends EventType>(event: E, callback: EventCallbackType<E>): void;
    getEngineTrackingCode(visitorCode: string): string;
    isInitialized(): boolean;
    setLogLevel(level: LogLevel): void;
    setForcedVariation({ visitorCode, experimentId, variationKey, forceTargeting, }: SetForcedVariationParametersType): void;
    protected setUserConsent({ visitorCode, consent, setData, }: SetUserConsentParametersType): void;
    private updateConsentData;
    private _isConsentProvided;
    private _getFeatureVariables;
    private _getActiveFeatureVariations;
    private _evaluate;
    private _isFFUnrestrictedByMEGroup;
    private _getFeatureVariation;
    private _isVisitorNotInHoldout;
    private _setForcedVariation;
    private static EvaluatedExperiment;
}
