import { VisitType } from '../requester';
import { BrowserDataType, BrowserType, IKameleoonData } from './types';
import { TrackingStatus } from '../types';
/**
 * @class
 * Browser - a class for creating an instance for browser of a certain type
 * */
export declare class Browser implements IKameleoonData {
    status: TrackingStatus;
    private browser;
    private version?;
    /**
     * @param {BrowserType} browser - one of the browser types available for data, if browser can not be found in a list, it can be marked as `BrowserType.Other`
     * @param {number | undefined} version - version of the browser, floating point number represents major and minor version of the browser
     * @example
     * ```ts
     * const browser = new Browser(BrowserType.Chrome, 86);
     * const browser = new Browser(BrowserType.Safari, 14.1);
     * ```
     * */
    constructor(browser: BrowserType, version?: number);
    get url(): string;
    get data(): BrowserDataType;
    /**
     * @private
     * @method _fromRaw - an internal method for creating a Browser instance from raw data
     * @param {BrowserDataType} data - a raw data
     * @return {Browser} a Browser instance
     * */
    static _fromRaw(data: BrowserDataType): Browser;
    /**
     * @private
     * @method _fromVisit - an internal method for creating an instance of Browser class from a visit
     * @param {VisitType} visit - a visit
     * @returns {Browser | undefined} an instance of Browser class or undefined if browser can not be found among visits
     * */
    static _fromVisit(visit: VisitType): Browser | undefined;
}
