import { VisitType } from '../requester';
import { ConversionDataType, ConversionParametersType, IKameleoonData } from './types';
import { TrackingStatus } from '../types';
/**
 * @class
 * Conversion - a class for creating an instance for conversion tracking
 * */
export declare class Conversion implements IKameleoonData {
    status: TrackingStatus;
    private goalId;
    private revenue;
    private negative;
    private id;
    private nonce;
    private metadata;
    /**
     * @param {ConversionParametersType} conversionParameters - an object with conversion parameters
     * */
    constructor({ goalId, revenue, negative, metadata, }: ConversionParametersType);
    set _id(id: number);
    set _nonce(nonce: string);
    get url(): string;
    get data(): ConversionDataType;
    private _encodeMetadata;
    /**
     * @private
     * @method _fromRaw - an internal method for creating a Conversion instance from raw data
     * @param {ConversionDataType} data - a raw data
     * @return {Conversion} a Conversion instance
     * */
    static _fromRaw(data: ConversionDataType): Conversion;
    private static parseMetadata;
    /**
     * @private
     * @method _listFromVisit - an internal method for returning a list of all Conversion instances
     * @param {VisitType} visit - a visits
     * @return {Conversion[]} - a list of Conversion instances
     * */
    static _listFromVisit(visit: VisitType): Conversion[];
    /**
     * @private
     * @method _updateFromVisit - an internal method for updating a list of Conversion instances with only goalId
     * @param {VisitType} visit - a visits
     * @param {Map<number, Conversion>} dataMap - a map of Conversion instances
     * */
    static _updateFromVisit(visit: VisitType, dataMap: Map<number, Conversion>): void;
}
