import { Result } from 'ts-res';
import { KameleoonError } from '../kameleoonError';
import { SegmentType, Tree } from '../targeting';
import { CustomData } from './customData';
import { DataManagerParametersType, KameleoonData, KameleoonDataType, KameleoonVisitorDataType, VisitorsDataType } from './types';
import { CustomDataConfigurationType } from '../clientConfiguration';
import { MappingIdentifierType } from '../storage/types';
interface IDataManager {
    storeData(data: VisitorsDataType): Result<void, KameleoonError>;
    storeTrackedData(data: VisitorsDataType): void;
    getTree(segment: SegmentType): Tree;
    clearTrees(): void;
    isPersistentCustomData(dataItem: KameleoonDataType): dataItem is CustomData;
    isUniqueIdentifier(visitorCode: string): boolean;
    getLinkedVisitor(visitorCode: string, index: number | null): string | null;
    getVisitorData(visitorCode: string): KameleoonVisitorDataType | undefined;
    getVisitorIdentifier(visitorCode: string): string;
    getPendingData(visitorCode: string): KameleoonDataType[];
    getUnsentData(visitorCode: string): KameleoonDataType[];
    getVisitorStoredDataTypes(visitorCode: string): Set<KameleoonData>;
    readonly identifierCustomDataIndex: number | null;
    readonly storedCustomDataIndexes: Set<number>;
    readonly trees: Map<string, Tree>;
    readonly unsentDataVisitors: string[];
}
export declare class DataManager implements IDataManager {
    private dataStorage;
    private infoStorage;
    private dataProcessor;
    private targetingTrees;
    private mappingIdentifierCustomDataIndex;
    private persistentCustomDataIndexes;
    private localCustomDataIndexes;
    private cleanupIntervalId;
    private packageInfo;
    constructor({ dataStorage, infoStorage, cleanupInterval, packageInfo, }: DataManagerParametersType);
    getUnsentData(visitorCode: string): KameleoonDataType[];
    getPendingData(visitorCode: string): KameleoonDataType[];
    private getDataFromRaw;
    storeTrackedData(data: VisitorsDataType): void;
    storeData(data: VisitorsDataType): Result<void, KameleoonError>;
    storeData(visitorCode: string, ...data: KameleoonDataType[]): Result<void, KameleoonError>;
    getTree(segment: SegmentType): Tree;
    clearTrees(): void;
    isPersistentCustomData(dataItem: KameleoonDataType): dataItem is CustomData;
    isUniqueIdentifier(visitorCode: string): boolean;
    getVisitorIdentifier(visitorCode: string): string;
    getMappingIdentifier(visitorCode: string): MappingIdentifierType | undefined;
    setMappingIdentifier(visitorCode: string, mappingIdentifier: MappingIdentifierType): void;
    getVisitorData(visitorCode: string): KameleoonVisitorDataType | undefined;
    getVisitorStoredDataTypes(visitorCode: string): Set<KameleoonData>;
    getLinkedVisitor(visitorCode: string): string | null;
    private mutUpdateTargetingData;
    private cleanupData;
    private processCustomData;
    get unsentDataVisitors(): string[];
    get identifierCustomDataIndex(): number | null;
    get trees(): Map<string, Tree>;
    get storedCustomDataIndexes(): Set<number>;
    set customDataIndexes(customData: CustomDataConfigurationType[]);
}
export {};
