import { VisitType } from '../requester';
import { IKameleoonData, OperatingSystemDataType, OperatingSystemType } from './types';
import { TrackingStatus } from '../types';
/**
 * @class
 * OperatingSystem - a class for creating an instance for Operating System of a certain type
 * */
export declare class OperatingSystem implements IKameleoonData {
    private operatingSystem;
    status: TrackingStatus;
    /**
     * @param {OperatingSystemType} operatingSystem - one of the available operating system types from `OperatingSystemType` enum
     * */
    constructor(operatingSystem: OperatingSystemType);
    get url(): string;
    get data(): OperatingSystemDataType;
    /**
     * @private
     * @method _fromRaw - a static method for creating an instance of OperatingSystem class from raw data
     * @param {OperatingSystemDataType} data - a raw data
     * @returns {OperatingSystem} an instance of OperatingSystem class
     * */
    static _fromRaw(data: OperatingSystemDataType): OperatingSystem;
    /**
     * @private
     * @method _fromVisit - a static method for creating an instance of OperatingSystem class from a visit
     * @param {VisitType} visit - a visit
     * @returns {OperatingSystem | undefined} an instance of OperatingSystem class or undefined
     * */
    static _fromVisit(visit: VisitType): OperatingSystem | undefined;
}
