import { VisitType } from '../requester';
import { IKameleoonData, PageViewDataType, PageViewParametersType, TimestampType } from './types';
import { TrackingStatus } from '../types';
/**
 * @class
 * PageView - a class for creating an instance of a page view data
 * */
export declare class PageView implements IKameleoonData {
    timestamps: TimestampType[];
    private urlAddress;
    private title;
    private nonce?;
    private referrers?;
    /**
     * @param {PageViewParametersType} pageViewParameters - an object with page view parameters
     * */
    constructor({ urlAddress, title, referrers }: PageViewParametersType);
    get url(): string;
    get status(): TrackingStatus;
    set status(status: TrackingStatus);
    set _nonce(nonce: string);
    get data(): PageViewDataType;
    /**
     * @private
     * @method _fromRaw - an internal method for creating a PageView instance from raw data
     * @param {PageViewDataType} data - a raw data
     * @return {PageView} a PageView instance
     * */
    static _fromRaw(data: PageViewDataType): PageView;
    /**
     * @private
     * @method _updateFromVisit - an internal method for updating a list of page view data from a visit
     * @param {VisitType} visit - a visit
     * @param {Map<string, PageView>} dataMap - a map of page view data where we collect data
     * */
    static _updateFromVisit(visit: VisitType, dataMap: Map<string, PageView>): void;
}
