/**
 * Interface for a logger that accepts log messages at different levels.
 */
export interface IExternalLogger {
    /**
     * @method log - logs a message at the specified log level.
     *
     * @param {LogLevel} level   the log level
     * @param {string} message the log message
     */
    log(level: LogLevel, message: string): void;
}
/**
 * Enumeration of log levels.
 */
export declare enum LogLevel {
    NONE = 0,
    ERROR = 1,
    WARNING = 2,
    INFO = 3,
    DEBUG = 4
}
type LogLevelNames = {
    [K in string & keyof typeof LogLevel as (typeof LogLevel)[K]]: K;
};
/**
 * Mapping of log levels to their string representations.
 */
export declare const LOG_LEVEL_NAMES: LogLevelNames;
export type LogInputType = TemplateStringsArray | string | (() => string);
export type LogParametersType = {
    level: LogLevel;
    strings: LogInputType;
    keys?: unknown[];
};
export {};
